@@ -51,11 +51,17 @@ ServerDetails = collections.namedtuple('ServerDetails', [
 class EventHub(object):
     '''Manage routing of events.'''
 
-    def __init__(self, server_url, api_user, api_key):
+    def __init__(self, server_url, api_user, api_key, headers=None, cookies=None):
         '''Initialise hub, connecting to ftrack *server_url*.
 
         *api_user* is the user to authenticate as and *api_key* is the API key
         to authenticate with.
+        
+        *cookies* should be an optional mapping (dict) of key-value pairs specifying
+        custom cookies that we need to pass in alongside the requests to the server.
+
+        *headers* should be an optional mapping (dict) of key-value pairs specifying
+        custom headers that we need to pass in alongside the requests to the server.
 
         '''
         super(EventHub, self).__init__()
@@ -120,6 +126,9 @@ class EventHub(object):
             url_parse_result.hostname,
             url_parse_result.port
         )
+        
+        self._cookies = cookies or {}
+        self._headers = headers or {}
 
     def get_server_url(self):
         '''Return URL to server.'''
@@ -206,7 +215,9 @@ class EventHub(object):
             # More information on how the timeout works can be found here:
             # https://docs.python.org/2/library/socket.html#socket.socket.setblocking
             self._connection = websocket.create_connection(
-                url, timeout=60, sslopt={"ssl_version": available_ssl_protocol}, enable_multithread= True
+                url, timeout=60, sslopt={"ssl_version": available_ssl_protocol},
+                enable_multithread= True, header=self._headers,
+                cookie=';'.join(['{0}={1}'.format(x, self._cookies[x]) for x in self._cookies.keys()])
             )
 
         except Exception as error:
@@ -263,13 +274,12 @@ class EventHub(object):
             except queue.Empty:
                 break
 
-
     @property
     def connected(self):
         '''Return if connected.'''
         return self._connection is not None and self._connection.connected
 
-    def disconnect(self, unsubscribe=True):
+    def disconnect(self, unsubscribe=True, reconnect=False):
         '''Disconnect from server.
 
         Raise :exc:`ftrack_api.exception.EventHubConnectionError` if not
@@ -278,6 +288,9 @@ class EventHub(object):
         If *unsubscribe* is True then unsubscribe all current subscribers
         automatically before disconnecting.
 
+        If *reconnect* is True we do not set connection_initialized to False so that
+        we may queue up messages that are published while disconnected.
+
         '''
         if not self.connected:
             raise ftrack_api.exception.EventHubConnectionError(
@@ -285,9 +298,12 @@ class EventHub(object):
             )
 
         else:
-            # Set flag to indicate disconnection was intentional.
             self._intentional_disconnect = True
 
+            if not reconnect:
+                # Set flag to indicate disconnection was intentional.
+                self._connection_initialised = False
+
             # Set blocking to true on socket to make sure unsubscribe events
             # are emitted before closing the connection.
             self._connection.sock.setblocking(1)
@@ -325,7 +341,10 @@ class EventHub(object):
 
         '''
         try:
-            self.disconnect(unsubscribe=False)
+            self.disconnect(
+                unsubscribe=False, reconnect=True
+            )
+
         except ftrack_api.exception.EventHubConnectionError:
             pass
 
@@ -674,10 +693,12 @@ class EventHub(object):
             return self._handle(event, synchronous=synchronous)
 
         if not self.connected:
-            if self._connection_initialised and not self._intentional_disconnect:
+            if self._connection_initialised:
                 # The connection is still being initialized, add
                 # the message to the queue and attempt to send it
-                # once connection has been established
+                # once connection has been established.
+
+                # This could also be a reconnection.
 
                 self._event_send_queue.put(
                     (event, synchronous, callback, on_reply)
@@ -839,16 +860,22 @@ class EventHub(object):
     def _get_socket_io_session(self):
         '''Connect to server and retrieve session information.'''
         socket_io_url = (
-            '{0}://{1}/socket.io/1/?api_user={2}&api_key={3}'
+            '{0}://{1}/socket.io/1/'
         ).format(
             self.server.scheme,
-            self.get_network_location(),
-            self._api_user,
-            self._api_key
+            self.get_network_location()
         )
         try:
+            req_headers = {
+                'ftrack-user': self._api_user,
+                'ftrack-api-key': self._api_key
+            }
+            if self._headers:
+                req_headers.update(self._headers)
             response = requests.get(
                 socket_io_url,
+                headers=req_headers,
+                cookies=self._cookies,
                 timeout=60  # 60 seconds timeout to recieve errors faster.
             )
         except requests.exceptions.Timeout as error:
