@@ -166,6 +166,50 @@ def test_connect(session):
     event_hub.disconnect()
 
 
+def test_connect_custom_headers(session):
+    '''Connect with custom headers passed in.'''
+    event_hub = ftrack_api.event.hub.EventHub(
+        session.server_url, session.api_user, session.api_key, headers={'abc': 'def'}
+    )
+    event_hub.connect()
+
+    assert (
+        'abc' in event_hub._headers.keys(),
+        event_hub._headers['abc'] == 'def',
+        event_hub.connected is True
+    )
+    event_hub.disconnect()
+
+
+def test_connect_strict_api_header(session):
+    '''Connect with ftrack-strict-api = True header passed in.'''
+    event_hub = ftrack_api.event.hub.EventHub(
+        session.server_url, session.api_user, session.api_key, headers={'ftrack-strict-api': 'true'}
+    )
+    event_hub.connect()
+
+    assert (
+        'ftrack-strict-api' in event_hub._headers.keys(),
+        event_hub._headers['ftrack-strict-api'] is True,
+        event_hub.connected is True
+    )
+    event_hub.disconnect()
+
+
+def test_connect_custom_cookies(session):
+    '''Connect with custom cookies passed in.'''
+    event_hub = ftrack_api.event.hub.EventHub(
+        session.server_url, session.api_user, session.api_key, cookies={'abc': 'def'}
+    )
+    event_hub.connect()
+
+    assert (
+        event_hub._cookies == 'abc=def',
+        event_hub.connected is True
+    )
+    event_hub.disconnect()
+
+
 def test_connect_when_already_connected(event_hub):
     '''Fail to connect when already connected'''
     assert event_hub.connected is True
@@ -222,6 +266,10 @@ def test_disconnect(event_hub):
     '''Disconnect and unsubscribe all subscribers.'''
     event_hub.disconnect()
     assert len(event_hub._subscribers) == 0
+
+    assert event_hub._intentional_disconnect is True
+    assert event_hub._connection_initialised is False
+
     assert event_hub.connected is False
 
 
@@ -230,6 +278,15 @@ def test_disconnect_without_unsubscribing(event_hub):
     event_hub.disconnect(unsubscribe=False)
     assert len(event_hub._subscribers) > 0
     assert event_hub.connected is False
+    assert event_hub._connection_initialised is False
+
+
+def test_disconnect_with_reconnect(event_hub):
+    '''Disconnect with the intention of reconnecting.'''
+    event_hub.disconnect(reconnect=True)
+    assert event_hub._connection_initialised is True
+
+    assert event_hub.connected is False
 
 
 def test_close_connection_from_manually_connected_hub(session_no_autoconnect_hub):
@@ -642,7 +699,7 @@ def test_publish_with_multiple_replies(event_hub):
 
     assert sorted(called['callback']) == ['One', 'Two']
 
-@pytest.mark.slow
+
 def test_server_heartbeat_response():
     '''Maintain connection by responding to server heartbeat request.'''
     test_script = os.path.join(
