@@ -14,6 +14,7 @@ import pytest
 import mock
 import arrow
 import requests
+import requests.utils
 
 import ftrack_api
 import ftrack_api.cache
@@ -216,8 +217,13 @@ def test_ensure_entity_with_non_string_data_types(session, mocker):
 
 def test_ensure_entity_with_identifying_keys(session, unique_name):
     '''Ensure entity, checking using keys subset and then creating.'''
+
+    unique_mail = 'test{0}@example.com'.format(
+        str(uuid.uuid4())
+    )
+
     entity = session.ensure(
-        'User', {'username': unique_name, 'email': 'test@example.com'},
+        'User', {'username': unique_name, 'email': unique_mail},
         identifying_keys=['username']
     )
     assert entity['username'] == unique_name
@@ -250,18 +256,28 @@ def test_ensure_existing_entity(session, unique_name):
 
 def test_ensure_update_existing_entity(session, unique_name):
     '''Ensure and update existing entity.'''
+
+    mail = 'test{0}@example.com'.format(
+        str(uuid.uuid4())
+    )
+
     entity = session.ensure(
-        'User', {'first_name': unique_name, 'email': 'anon@example.com'}
+        'User', {'first_name': unique_name, 'email': mail}
+    )
+    assert entity['email'] == mail
+
+    updated_mail = 'test{0}@example.com'.format(
+        str(uuid.uuid4())
     )
-    assert entity['email'] == 'anon@example.com'
 
     # Second call should commit updates.
     retrieved = session.ensure(
-        'User', {'first_name': unique_name, 'email': 'test@example.com'},
+        'User', {'first_name': unique_name, 'email': updated_mail},
         identifying_keys=['first_name']
     )
+
     assert retrieved == entity
-    assert retrieved['email'] == 'test@example.com'
+    assert retrieved['email'] == updated_mail
 
 
 def test_reconstruct_entity(session):
@@ -1137,6 +1153,10 @@ def test_get_info_widget_url(session, task):
     response.raise_for_status()
 
 
+@pytest.mark.xfail(
+    raises=ftrack_api.exception.ServerError,
+    reason='Testing environment does not support encoding'
+)
 def test_encode_media_from_path(session, video_path):
     '''Encode media based on a file path.'''
     job = session.encode_media(video_path)
@@ -1152,6 +1172,10 @@ def test_encode_media_from_path(session, video_path):
     assert 'format' in job_data['output'][0]
 
 
+@pytest.mark.xfail(
+    raises=ftrack_api.exception.ServerError,
+    reason='Testing environment does not support encoding'
+)
 def test_encode_media_from_component(session, video_path):
     '''Encode media based on a component.'''
     location = session.query('Location where name is "ftrack.server"').one()
@@ -1516,3 +1540,33 @@ def test_operation_recoding_thread_dependent(session, propagating_thread):
         assert operation.entity_type == 'User'
         assert operation.entity_key['id'] == _id
 
+
+def test_strict_api_header():
+    '''Create ftrack session containing ftrack-strict-api = True header.'''
+    new_session = ftrack_api.Session(strict_api=True)
+    
+    assert(
+        'ftrack-strict-api' in new_session._request.headers.keys(),
+        new_session._request.headers['ftrack-strict-api'] == 'true'
+    )
+
+
+def test_custom_cookies_session():
+    '''Create ftrack session containing custom cookies.'''
+    new_session = ftrack_api.Session(cookies={'abc': 'def'})
+    cookies_dict = requests.utils.dict_from_cookiejar(new_session._request.cookies)
+
+    assert(
+        'abc' in cookies_dict.keys(),
+        cookies_dict['abc'] == 'def'
+    )
+
+
+def test_custom_headers_session():
+    '''Create ftrack session containing custom headers.'''
+    new_session = ftrack_api.Session(headers={'abc': 'def'})
+
+    assert(
+        'abc' in new_session._request.headers.keys(),
+        new_session._request.headers['abc'] == 'def'
+    )   
